import PropTypes from 'prop-types';
import { BaseProps } from '../types';
import { SpinnerSize, SpinnerVariant } from './types';
interface Props extends BaseProps {
    isVisible?: boolean;
    size?: SpinnerSize;
    variant?: SpinnerVariant;
}
/**
 * Spinners should be shown when retrieving data or performing slow,
 * help to reassure the user that the system is actively retrieving data.
 */
declare const Spinner: {
    ({ size, variant, isVisible, style }: Props): JSX.Element | null;
    propTypes: {
        /**
         * Show/Hide the spinner
         * */
        isVisible: PropTypes.Requireable<boolean>;
        /**
         * The size of the spinner. Accepted sizes are small, medium and large.
         * This values defaults to medium.
         */
        size: PropTypes.Requireable<string>;
        /**
         * The variant changes the appearance of the spinner.
         * Accepted variants are base and neutral.
         * This value defaults to brand.
         */
        variant: PropTypes.Requireable<string>;
        style: PropTypes.Requireable<object>;
    };
    defaultProps: {
        isVisible: boolean;
        size: string;
        variant: string;
        style: undefined;
    };
};
export default Spinner;
